@@ -3,13 +3,13 @@
 import zerorpc
 import os
 import pprint
-import workbench_client
+import client_helper
 
 def run():
     """This client pulls PCAP meta data."""
     
     # Grab server args
-    args = workbench_client.grab_server_args()
+    args = client_helper.grab_server_args()
 
     # Start up workbench connection
     workbench = zerorpc.Client(timeout=300, heartbeat=60)
@@ -24,9 +24,10 @@ def run():
         if '.DS_Store' in filename: continue
 
         with open(filename,'rb') as f:
-            md5 = workbench.store_sample(filename, f.read(), 'pcap')
+            base_name = os.path.basename(filename)
+            md5 = workbench.store_sample(f.read(), base_name, 'pcap')
             results = workbench.work_request('view_pcap', md5)
-            print 'Filename: %s results:' % (filename)
+            print 'Filename: %s results:' % (base_name)
             pprint.pprint(results)
 
 def test():
