@@ -150,12 +150,13 @@ class MemoryImageProcDump(object):
 
 # Unit test: Create the class, the proper input and run the execute() method for a test
 import pytest
-@pytest.mark.rekall
+#pylint: disable=no-member
+@pytest.mark.xfail
+#pylint: enable=no-member
 def test():
     ''' mem_procdump.py: Test '''
 
     # This worker test requires a local server running
-    import zerorpc
     workbench = zerorpc.Client(timeout=300, heartbeat=60)
     workbench.connect("tcp://127.0.0.1:4242")
 
